==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/ytbchoicewithcontainerandleaflist/rev20160826/ytbchoicewithcontainerandleaflist/contenttest/choicecontainer/choicecontainer/DefaultPredict.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.choicecontainer;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.choicecontainer.predict.Reproduce;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of predict.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultPredict extends InnerModelObject 
        implements Predict, MultiInstanceObject<PredictKeys> {
    protected Reproduce reproduce;

    @Override
    public Reproduce reproduce() {
        return reproduce;
    }

    @Override
    public void reproduce(Reproduce reproduce) {
        this.reproduce = reproduce;
    }

    @Override
    public int hashCode() {
        return Objects.hash(reproduce);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultPredict) {
            DefaultPredict other = (DefaultPredict) obj;
            return
                Objects.equals(reproduce, other.reproduce);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("reproduce=" + reproduce)
            .toString();
    }


    /**
     * Creates an instance of defaultPredict.
     */
    public DefaultPredict() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ytbchoicewithcontainerandleaflist/rev20160826/ytbchoicewithcontainerandleaflist/contenttest/choicecontainer/choicecontainer/DefaultPredict.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.choicecontainer;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.contenttest.choicecontainer.choicecontainer.predict.Reproduce;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of predict.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultPredict extends InnerModelObject 
        implements Predict, MultiInstanceObject<PredictKeys> {
    protected Reproduce reproduce;

    @Override
    public Reproduce reproduce() {
        return reproduce;
    }

    @Override
    public void reproduce(Reproduce reproduce) {
        this.reproduce = reproduce;
    }

    @Override
    public int hashCode() {
        return Objects.hash(reproduce);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultPredict) {
            DefaultPredict other = (DefaultPredict) obj;
            return
                Objects.deepEquals(reproduce, other.reproduce);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("reproduce=" + reproduce)
            .toString();
    }


    /**
     * Creates an instance of defaultPredict.
     */
    public DefaultPredict() {
    }

}
